// import { login, logout, getInfo } from '@/api/user'
import { login, getInfo } from '@/api/user'
import { getOrganizeInfo } from '@/api/other'
import { getToken, setToken, removeToken } from '@/utils/auth'
import router, { resetRouter } from '@/router'
// import store from '@/store'

const state = {
  token: getToken(),
  name: '',
  avatar: '',
  systemName: '',
  systemImage: '',
  roles: []
}

const mutations = {
  SET_TOKEN: (state, token) => {
    state.token = token
  },
  SET_SYSTEM_NAME: (state, systemName) => {
    state.systemName = systemName
  },
  SET_SYSTEM_IMAGE: (state, systemImage) => {
    state.systemImage = systemImage
  },
  SET_NAME: (state, name) => {
    state.name = name
  },
  SET_AVATAR: (state, avatar) => {
    state.avatar = avatar
  },
  SET_ROLES: (state, roles) => {
    state.roles = roles
  }
}

const actions = {
  getSysInfo: function({ commit, state }, organizeID) {
    return new Promise((resolve, reject) => {
      getOrganizeInfo({ id: organizeID }).then(response => {
        const { data } = response
        if (data) {
          const { systemName, systemImage } = data
          commit('SET_SYSTEM_NAME', systemName)
          commit('SET_SYSTEM_IMAGE', systemImage)
        }
        resolve(data)
      }).catch(error => {
        reject(error)
      })
    })
  },

  // user login
  login: function({ commit }, userInfo) {
    const { account, password, organizeID } = userInfo
    return new Promise((resolve, reject) => {
      login({ account: account.trim(), password: password, organizeID: organizeID }).then(response => {
        const { data } = response
        commit('SET_TOKEN', data)
        setToken(data)
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },

  // get user info
  getInfo({ commit, state }) {
    return new Promise((resolve, reject) => {
      getInfo(state.token).then(response => {
        // const { data } = response
        const data = response.data
        if (!data) {
          reject('Verification failed, please Login again.')
        }
        /* const { roles, account, avatar, introduction } = data
        if (!roles || roles.length <= 0) {
          reject('getInfo: roles must be a non-null array!')
        } */
        data.roles = ['admin']
        const { roles, accountName, avatar } = data
        commit('SET_ROLES', roles)
        commit('SET_NAME', accountName)
        commit('SET_AVATAR', avatar)
        // commit('SET_SYSTEM_NAME', introduction)
        resolve(data)
      }).catch(error => {
        reject(error)
      })
    })
  },

  // user logout
  logout({ commit, state, dispatch }) {
    return new Promise((resolve, reject) => {
      // logout(state.token).then(() => {
      commit('SET_TOKEN', '')
      commit('SET_ROLES', [])
      removeToken()
      resetRouter()

      // reset visited views and cached views
      // to fixed https://github.com/PanJiaChen/vue-element-admin/issues/2485
      dispatch('tagsView/delAllViews', null, { root: true })

      resolve()
      // }).catch(error => {
      //  reject(error)
      // })
    })
  },

  // remove token
  resetToken({ commit }) {
    return new Promise(resolve => {
      commit('SET_TOKEN', '')
      commit('SET_ROLES', [])
      removeToken()
      resolve()
    })
  },

  // dynamically modify permissions
  changeRoles({ commit, dispatch }, role) {
    return new Promise(async resolve => {
      const token = role + '-token'

      commit('SET_TOKEN', token)
      setToken(token)

      const { roles } = await dispatch('getInfo')

      resetRouter()

      // generate accessible routes map based on roles
      const accessRoutes = await dispatch('permission/generateRoutes', roles, { root: true })

      // dynamically add accessible routes
      router.addRoutes(accessRoutes)

      // reset visited views and cached views
      dispatch('tagsView/delAllViews', null, { root: true })

      resolve()
    })
  }

}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
